dadi.DFE API documentation
Description: Fitting Distributions of Fitness Effects to population genomic data, both single-population and joint.

# Module `dadi.DFE`

Fitting Distributions of Fitness Effects to population genomic data, both single-population and joint.

Expand source code

    """
    Fitting Distributions of Fitness Effects to population genomic data, both single-population and joint.
    """
    from dadi.DFE.Cache1D_mod import Cache1D
    from dadi.DFE.Cache2D_mod import Cache2D, mixture, mixture_symmetric_point_pos
    from dadi.DFE import PDFs, DemogSelModels, Plotting

## Sub-modules

`dadi.DFE.Cache1D_mod`

  Initially developed by Bernard Kim and published as fitdadi Kim, Huber, Lohmueller (2017) Genetics. Modified version of the script found at: …

`dadi.DFE.Cache2D_mod`

  Developed by the Gutenkunst group, building off of the fitdadi code.

`dadi.DFE.DemogSelModels`

  Input models of demography + selection.

`dadi.DFE.PDFs`

  Probability density functions for defining DFEs.

`dadi.DFE.PDFs_c`

  This module 'PDFs_c' is auto-generated with f2py (version:2).

  ## Functions

  output = biv_lognormal(xx,yy,params) y = gamma_func(z) output = …

`dadi.DFE.Plotting`

  Miscellaneous functions for plotting DFEs